@@ -6,7 +6,7 @@ import ADTypes: AutoFiniteDiff, AutoForwardDiff, AbstractADType, AutoSparse
 import ForwardDiff, FiniteDiff
 import ForwardDiff.Dual
 import LinearSolve
-import LinearSolve: OperatorAssumptions
+import LinearSolve: OperatorAssumptions, LinearVerbosity
 import FunctionWrappersWrappers
 import DiffEqBase
 
@@ -35,7 +35,7 @@ using OrdinaryDiffEqCore: OrdinaryDiffEqAlgorithm, OrdinaryDiffEqAdaptiveImplici
                           DAEAlgorithm,
                           OrdinaryDiffEqImplicitAlgorithm, CompositeAlgorithm,
                           OrdinaryDiffEqExponentialAlgorithm,
-                          OrdinaryDiffEqAdaptiveExponentialAlgorithm, @unpack,
+                          OrdinaryDiffEqAdaptiveExponentialAlgorithm,
                           AbstractNLSolver, nlsolve_f, issplit,
                           concrete_jac, unwrap_alg, OrdinaryDiffEqCache, _vec, standardtag,
                           isnewton, _unwrap_val,
