@@ -29,8 +29,8 @@ Base.:\(W::StaticWOperator, v::AbstractArray) = isinv(W) ? W.W * v : W.F \ v
 
 function calc_tderivative!(integrator, cache, dtd1, repeat_step)
     @inbounds begin
-        @unpack t, dt, uprev, u, f, p = integrator
-        @unpack du2, fsalfirst, dT, tf, linsolve_tmp = cache
+        (; t, dt, uprev, u, f, p) = integrator
+        (; du2, fsalfirst, dT, tf, linsolve_tmp) = cache
 
         # Time derivative
         if !repeat_step # skip calculation if step is repeated
@@ -75,7 +75,7 @@ function calc_tderivative!(integrator, cache, dtd1, repeat_step)
 end
 
 function calc_tderivative(integrator, cache)
-    @unpack t, dt, uprev, u, f, p, alg = integrator
+    (; t, dt, uprev, u, f, p, alg) = integrator
 
     # Time derivative
     if SciMLBase.has_tgrad(f)
@@ -116,7 +116,7 @@ either automatic or finite differencing will be used depending on the `uf` objec
 cache. If `next_step`, then it will evaluate the Jacobian at the next step.
 """
 function calc_J(integrator, cache, next_step::Bool = false)
-    @unpack dt, t, uprev, f, p, alg = integrator
+    (; dt, t, uprev, f, p, alg) = integrator
     if next_step
         t = t + dt
         uprev = integrator.u
@@ -128,7 +128,7 @@ function calc_J(integrator, cache, next_step::Bool = false)
             uf = cache.uf
             J = f.jac(duprev, uprev, p, uf.α * uf.invγdt, t)
         else
-            @unpack uf = cache
+            (; uf) = cache
             x = zero(uprev)
             J = jacobian(uf, x, integrator)
         end
@@ -136,7 +136,7 @@ function calc_J(integrator, cache, next_step::Bool = false)
         if SciMLBase.has_jac(f)
             J = f.jac(uprev, p, t)
         else
-            @unpack uf = cache
+            (; uf) = cache
 
             uf.f = nlsolve_f(f, alg)
             uf.p = p
@@ -163,7 +163,7 @@ either automatic or finite differencing will be used depending on the `cache`.
 If `next_step`, then it will evaluate the Jacobian at the next step.
 """
 function calc_J!(J, integrator, cache, next_step::Bool = false)
-    @unpack dt, t, uprev, f, p, alg = integrator
+    (; dt, t, uprev, f, p, alg) = integrator
     if next_step
         t = t + dt
         uprev = integrator.u
@@ -188,7 +188,7 @@ function calc_J!(J, integrator, cache, next_step::Bool = false)
                 f.jac(J, duprev, uprev, p, uf.α * uf.invγdt, t)
             end
         else
-            @unpack du1, uf, jac_config = cache
+            (; du1, uf, jac_config) = cache
             # using `dz` as temporary array
             x = cache.dz
             uf.t = t
@@ -212,7 +212,7 @@ function calc_J!(J, integrator, cache, next_step::Bool = false)
                 f.jac(J, uprev, p, t)
             end
         else
-            @unpack du1, uf, jac_config = cache
+            (; du1, uf, jac_config) = cache
             uf.f = nlsolve_f(f, alg)
             uf.t = t
             if !(p isa SciMLBase.NullParameters)
@@ -572,7 +572,7 @@ is_always_new(alg) = isdefined(alg, :always_new) ? alg.always_new : false
 
 function calc_W!(W, integrator, nlsolver::Union{Nothing, AbstractNLSolver}, cache, dtgamma,
         repeat_step, newJW = nothing)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     lcache = nlsolver === nothing ? cache : nlsolver.cache
     next_step = is_always_new(nlsolver)
     if next_step
@@ -580,9 +580,10 @@ function calc_W!(W, integrator, nlsolver::Union{Nothing, AbstractNLSolver}, cach
         uprev = integrator.u
     end
 
-    @unpack J = lcache
+    (; J) = lcache
     isdae = integrator.alg isa DAEAlgorithm
     alg = unwrap_alg(integrator, true)
+    mass_matrix = nothing
     if !isdae
         mass_matrix = integrator.f.mass_matrix
     end
@@ -652,7 +653,7 @@ function calc_W!(W, integrator, nlsolver::Union{Nothing, AbstractNLSolver}, cach
 end
 
 @noinline function calc_W(integrator, nlsolver, dtgamma, repeat_step)
-    @unpack t, uprev, p, f = integrator
+    (; t, uprev, p, f) = integrator
 
     next_step = is_always_new(nlsolver)
     if next_step
@@ -663,6 +664,7 @@ end
     cache = nlsolver isa OrdinaryDiffEqCache ? nlsolver : nlsolver.cache
 
     isdae = integrator.alg isa DAEAlgorithm
+    mass_matrix = nothing
     if !isdae
         mass_matrix = integrator.f.mass_matrix
     end
@@ -672,6 +674,7 @@ end
     islin, isode = islinearfunction(integrator)
     !isdae && update_coefficients!(mass_matrix, uprev, p, t)
 
+    J = nothing
     if cache.W isa StaticWOperator
         integrator.stats.nw += 1
         J = calc_J(integrator, cache, next_step)
@@ -866,10 +869,10 @@ build_uf(alg, nf, t, p, ::Val{false}) = UDerivativeWrapper(nf, t, p)
 function LinearSolve.init_cacheval(
         alg::LinearSolve.DefaultLinearSolver, A::WOperator, b, u,
         Pl, Pr,
-        maxiters::Int, abstol, reltol, verbose::Bool,
+        maxiters::Int, abstol, reltol, verbose::Union{LinearVerbosity,Bool},
         assumptions::OperatorAssumptions)
     LinearSolve.init_cacheval(alg, A.J, b, u, Pl, Pr,
-        maxiters::Int, abstol, reltol, verbose::Bool,
+        maxiters::Int, abstol, reltol, verbose::Union{LinearVerbosity,Bool},
         assumptions::OperatorAssumptions)
 end
 
@@ -897,10 +900,10 @@ for alg in [LinearSolve.AppleAccelerateLUFactorization,
     LinearSolve.SparspakFactorization,
     LinearSolve.UMFPACKFactorization]
     @eval function LinearSolve.init_cacheval(alg::$alg, A::WOperator, b, u, Pl, Pr,
-            maxiters::Int, abstol, reltol, verbose::Bool,
+            maxiters::Int, abstol, reltol, verbose::Union{LinearVerbosity,Bool},
             assumptions::OperatorAssumptions)
         LinearSolve.init_cacheval(alg, A.J, b, u, Pl, Pr,
-            maxiters::Int, abstol, reltol, verbose::Bool,
+            maxiters::Int, abstol, reltol, verbose::Union{LinearVerbosity,Bool},
             assumptions::OperatorAssumptions)
     end
 end
@@ -908,7 +911,7 @@ end
 function resize_J_W!(cache, integrator, i)
     (isdefined(cache, :J) && isdefined(cache, :W)) || return
 
-    @unpack f = integrator
+    (; f) = integrator
 
     if cache.W isa WOperator
         nf = nlsolve_f(f, integrator.alg)
